import { create } from 'zustand';
import { query } from '@/modules';
import { message } from '@/modules/message';
type OrgStore = {
  showEdit: boolean;
  setShowEdit: (showEdit: boolean) => void;
  formData: any;
  setFormData: (formData: any) => void;
  showUserEdit: boolean;
  setShowUserEdit: (showUserEdit: boolean) => void;
  userFormData: any;
  setUserFormData: (userFormData: any) => void;
  loading: boolean;
  setLoading: (loading: boolean) => void;
  list: any[];
  getList: () => Promise<void>;
  updateData: (data: any) => Promise<void>;
  deleteData: (id: string) => Promise<void>;
  org: any;
  setOrg: (org: any) => void;
  users: { id: string; username: string; role?: string }[];
  orgId: string;
  setOrgId: (orgId: string) => void;
  getOrg: () => Promise<any>;
  addUser: (data: { userId?: string; username?: string; role?: string }) => Promise<void>;
  removeUser: (userId: string) => Promise<void>;
};
export const useOrgStore = create<OrgStore>((set, get) => {
  return {
    showEdit: false,
    setShowEdit: (showEdit) => set({ showEdit }),
    formData: {},
    setFormData: (formData) => set({ formData }),
    loading: false,
    setLoading: (loading) => set({ loading }),
    showUserEdit: false,
    setShowUserEdit: (showUserEdit) => set({ showUserEdit }),
    userFormData: {},
    setUserFormData: (userFormData) => set({ userFormData }),
    list: [],
    getList: async () => {
      set({ loading: true });

      const res = await query.post({
        path: 'org',
        key: 'list',
      });
      set({ loading: false });
      if (res.code === 200) {
        set({ list: res.data });
      } else {
        message.error(res.message || 'Request failed');
      }
    },
    updateData: async (data) => {
      const { getList } = get();
      const res = await query.post({
        path: 'org',
        key: 'update',
        data,
      });
      if (res.code === 200) {
        message.success('Success');
        set({ showEdit: false, formData: [] });
        getList();
      } else {
        message.error(res.message || 'Request failed');
      }
    },
    deleteData: async (id) => {
      const { getList } = get();
      const res = await query.post({
        path: 'org',
        key: 'delete',
        id,
      });
      if (res.code === 200) {
        getList();
        message.success('Success');
      } else {
        message.error(res.message || 'Request failed');
      }
    },
    org: {},
    setOrg: (org) => set({ org }),
    orgId: '',
    setOrgId: (orgId) => set({ orgId }),
    users: [],
    getOrg: async () => {
      const { orgId } = get();
      const res = await query.post({
        path: 'org',
        key: 'get',
        id: orgId,
      });
      if (res.code === 200) {
        const { org, users } = res.data || {};
        set({ org, users });
        message.success('load success');
      } else {
        message.error(res.message || 'Request failed');
      }
    },
    addUser: async (data) => {
      const { orgId } = get();
      const res = await query.post({
        path: 'org-user',
        key: 'operate',
        data: { orgId, ...data, action: 'add' },
      });
      if (res.code === 200) {
        message.success('Success');
        get().getOrg();
      } else {
        message.error(res.message || 'Request failed');
      }
    },
    removeUser: async (userId: string) => {
      const { orgId } = get();
      const res = await query.post({
        path: 'org-user',
        key: 'operate',
        data: {
          orgId,
          userId,
          action: 'remove',
        },
      });
      if (res.code === 200) {
        message.success('Success');
        get().getOrg();
      } else {
        message.error(res.message || 'Request failed');
      }
    },
  };
});
